@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.h,v 1.51 2004/02/26 16:46:51 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.h,v 1.53 2004/05/17 17:41:44 padraigo Exp $
  *
  *  Copyright (c) 1987-2003 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -296,7 +296,7 @@ struct calcVars {                      /* Calctool variables and options. */
     int show_zeroes;   /* Set if trailing zeroes should be shown. */
     int started;       /* Set just before window is displayed. */
     int toclear;       /* Indicates if display should be cleared. */
-} CalcVars;
+};
 
 typedef struct calcVars *Vars;
 
@@ -389,7 +389,7 @@ void read_str(char **, char *);
 void save_pending_values(struct button *);
 void save_resources();
 void set_accuracy_toggle(int);
-void set_display(char *);
+void set_display(char *, int);
 void set_error_state(int);
 void set_hyp_item(int);
 void set_ins_key();
